/* This file is part of the KDE project
 *
 * Copyright (C) 2001-2003 George Staikos <staikos@kde.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */ 

#ifndef __INC_KSSL_ALL_H
#define __INC_KSSL_ALL_H
#include <ksslcertificatefactory.h>
#include <ksslinfodlg.h>
#include <ksslx509map.h>
#include <kssl.h>
#include <ksslcertificatehome.h>
#include <ksslpeerinfo.h>
#include <ksslcertificate.h>
#include <ksslconnectioninfo.h>
#include <ksslsettings.h>
#include <ksslcertificatecache.h>
#include <ksslutils.h>
#include <ksslpkcs7.h>
#include <ksslpkcs12.h>
#include <ksslcertchain.h>
#include <ksslx509v3.h>
#include <ksslsigners.h>
#include <ksslsession.h>
#endif

